from typing import overload
from typing import List
from typing import Mapping
from .HTTPRequest_Response import HTTPRequest_Response


class HTTPRequest:
	"""
	Since: 1.1.8 
	"""
	headers: Mapping[str, str]
	conn: URL
	connectTimeout: int
	readTimeout: int

	@overload
	def __init__(self, url: str) -> None:
		pass

	@overload
	def addHeader(self, key: str, value: str) -> "HTTPRequest":
		"""
		Since: 1.1.8 

		Args:
			value: 
			key: 
		"""
		pass

	@overload
	def setConnectTimeout(self, timeout: int) -> "HTTPRequest":
		"""
		Since: 1.8.6 
		"""
		pass

	@overload
	def setReadTimeout(self, timeout: int) -> "HTTPRequest":
		"""
		Since: 1.8.6 
		"""
		pass

	@overload
	def get(self) -> HTTPRequest_Response:
		"""
		Since: 1.1.8 
		"""
		pass

	@overload
	def post(self, data: str) -> HTTPRequest_Response:
		"""
		Since: 1.1.8 

		Args:
			data: 
		"""
		pass

	@overload
	def post(self, data: List[float]) -> HTTPRequest_Response:
		"""
		Since: 1.8.4 

		Args:
			data: 
		"""
		pass

	@overload
	def put(self, data: str) -> HTTPRequest_Response:
		"""
		Since: 1.8.4 

		Args:
			data: 
		"""
		pass

	@overload
	def put(self, data: List[float]) -> HTTPRequest_Response:
		"""
		Since: 1.8.4 

		Args:
			data: 
		"""
		pass

	@overload
	def send(self, method: str) -> HTTPRequest_Response:
		"""
		Since: 1.8.6 
		"""
		pass

	@overload
	def send(self, method: str, data: str) -> HTTPRequest_Response:
		"""
		Since: 1.8.4 

		Args:
			method: 
			data: 
		"""
		pass

	@overload
	def send(self, method: str, data: List[float]) -> HTTPRequest_Response:
		"""
		Since: 1.8.4 

		Args:
			method: 
			data: 
		"""
		pass

	pass





from typing import overload
from .RecipeInventory import RecipeInventory
from .ItemStackHelper import ItemStackHelper


class CraftingInventory(RecipeInventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def getInput(self, x: int, y: int) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the input from 0 to 2, going left to right 
			y: the y position of the input from 0 to 2, going top to bottom 

		Returns:
			the input item at the given position. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from .Inventory import Inventory


class BeaconInventory(Inventory):
	"""
	Since: 1.5.1 
	"""

	@overload
	def getLevel(self) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def getFirstEffect(self) -> str:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def getSecondEffect(self) -> str:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def selectFirstEffect(self, id: str) -> bool:
		"""
		Since: 1.5.1 

		Args:
			id: 
		"""
		pass

	@overload
	def selectSecondEffect(self, id: str) -> bool:
		"""
		Since: 1.5.1 

		Args:
			id: 
		"""
		pass

	@overload
	def applyEffects(self) -> bool:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IllagerEntityHelper import IllagerEntityHelper

net_minecraft_entity_mob_PillagerEntity = TypeVar("net_minecraft_entity_mob_PillagerEntity")
PillagerEntity = net_minecraft_entity_mob_PillagerEntity


class PillagerEntityHelper(IllagerEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PillagerEntity) -> None:
		pass

	@overload
	def isCaptain(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this pillager is a captain, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload


class TickSync_TickSyncInt(Comparable):
	tick: int

	@overload
	def __init__(self, tick: int) -> None:
		pass

	@overload
	def compareTo(self, o: "TickSync_TickSyncInt") -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .AnimalEntityHelper import AnimalEntityHelper

T = TypeVar("T")

class AbstractHorseEntityHelper(Generic[T], AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: T) -> None:
		pass

	@overload
	def getOwner(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the UUID of this horse's owner, or 'null' if it has no owner. 
		"""
		pass

	@overload
	def isTame(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this horse is already tamed, 'false' otherwise. 
		"""
		pass

	@overload
	def isSaddled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this horse is saddled, 'false' otherwise. 
		"""
		pass

	@overload
	def isAngry(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this horse is angry, 'false' otherwise. 
		"""
		pass

	@overload
	def isBred(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this horse was bred and not naturally spawned, 'false' otherwise. 
		"""
		pass

	@overload
	def isEating(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this horse is currently eating, 'false' otherwise. 
		"""
		pass

	@overload
	def canWearArmor(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this horse can wear armor, 'false' otherwise. 
		"""
		pass

	@overload
	def canBeSaddled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this horse can be saddled, 'false' otherwise. 
		"""
		pass

	@overload
	def getInventorySize(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			this horse's inventory size. 
		"""
		pass

	@overload
	def getJumpStrengthStat(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			this horse's jump strength. 
		"""
		pass

	@overload
	def getHorseJumpHeight(self) -> float:
		"""The result of this method is only an approximation, but it's really close.\n
		Since: 1.8.4 

		Returns:
			this horse's maximum jump height for its current jump strength. 
		"""
		pass

	@overload
	def getMaxJumpStrengthStat(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum possible value of a horse's jump strength. 
		"""
		pass

	@overload
	def getMinJumpStrengthStat(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the minimum possible value of a horse's jump strength. 
		"""
		pass

	@overload
	def getSpeedStat(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			this horse's speed stat. 
		"""
		pass

	@overload
	def getHorseSpeed(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			this horse's speed in blocks per second. 
		"""
		pass

	@overload
	def getMaxSpeedStat(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the maximum possible value of a horse's speed stat. 
		"""
		pass

	@overload
	def getMinSpeedStat(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the minimum possible value of a horse's speed stat. 
		"""
		pass

	@overload
	def getHealthStat(self) -> float:
		"""The returned value is equal to LivingEntityHelper#getMaxHealth() .\n
		Since: 1.8.4 

		Returns:
			this horse's health stat. 
		"""
		pass

	@overload
	def getMaxHealthStat(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the maximum possible value of a horse's health stat. 
		"""
		pass

	@overload
	def getMinHealthStat(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the minimum possible value of a horse's health stat. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .DisplayEntityHelper import DisplayEntityHelper
from .TextDisplayEntityHelper_TextDisplayDataHelper import TextDisplayEntityHelper_TextDisplayDataHelper

net_minecraft_entity_decoration_DisplayEntity_TextDisplayEntity = TypeVar("net_minecraft_entity_decoration_DisplayEntity_TextDisplayEntity")
DisplayEntity_TextDisplayEntity = net_minecraft_entity_decoration_DisplayEntity_TextDisplayEntity


class TextDisplayEntityHelper(DisplayEntityHelper):
	"""
	Since: 1.9.1 
	"""

	@overload
	def __init__(self, base: DisplayEntity_TextDisplayEntity) -> None:
		pass

	@overload
	def getData(self) -> TextDisplayEntityHelper_TextDisplayDataHelper:
		"""
		Since: 1.9.1 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_screen_slot_SlotActionType = TypeVar("net_minecraft_screen_slot_SlotActionType")
SlotActionType = net_minecraft_screen_slot_SlotActionType

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo

net_minecraft_screen_slot_Slot = TypeVar("net_minecraft_screen_slot_Slot")
Slot = net_minecraft_screen_slot_Slot


class MixinHandledScreen:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def beforeMouseClick(self, slot: Slot, slotId: int, button: int, actionType: SlotActionType, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_StriderEntity = TypeVar("net_minecraft_entity_passive_StriderEntity")
StriderEntity = net_minecraft_entity_passive_StriderEntity


class StriderEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: StriderEntity) -> None:
		pass

	@overload
	def isSaddled(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this strider is saddled, 'false' otherwise. 
		"""
		pass

	@overload
	def isShivering(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this strider is shivering in the cold, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from .Pos3D import Pos3D
from .Vec2D import Vec2D


class Pos2D:
	"""
	Since: 1.2.6 [citation needed] 
	"""
	ZERO: "Pos2D"
	x: float
	y: float

	@overload
	def __init__(self, x: float, y: float) -> None:
		pass

	@overload
	def getX(self) -> float:
		pass

	@overload
	def getY(self) -> float:
		pass

	@overload
	def add(self, pos: "Pos2D") -> "Pos2D":
		pass

	@overload
	def add(self, x: float, y: float) -> "Pos2D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def sub(self, pos: "Pos2D") -> "Pos2D":
		"""
		Since: 1.8.4 

		Args:
			pos: the position to subtract 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def sub(self, x: float, y: float) -> "Pos2D":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to subtract 
			y: the y coordinate to subtract 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def multiply(self, pos: "Pos2D") -> "Pos2D":
		pass

	@overload
	def multiply(self, x: float, y: float) -> "Pos2D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def divide(self, pos: "Pos2D") -> "Pos2D":
		"""
		Since: 1.8.4 

		Args:
			pos: the position to divide by 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def divide(self, x: float, y: float) -> "Pos2D":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to divide by 
			y: the y coordinate to divide by 

		Returns:
			the new position. 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "Pos2D":
		"""
		Since: 1.6.3 

		Args:
			scale: 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def to3D(self) -> Pos3D:
		pass

	@overload
	def toVector(self) -> Vec2D:
		pass

	@overload
	def toVector(self, start_pos: "Pos2D") -> Vec2D:
		"""
		Since: 1.6.4 

		Args:
			start_pos: 
		"""
		pass

	@overload
	def toVector(self, start_x: float, start_y: float) -> Vec2D:
		"""
		Since: 1.6.4 

		Args:
			start_x: 
			start_y: 
		"""
		pass

	@overload
	def toReverseVector(self) -> Vec2D:
		"""
		Since: 1.6.4 
		"""
		pass

	@overload
	def toReverseVector(self, end_pos: "Pos2D") -> Vec2D:
		"""
		Since: 1.6.4 

		Args:
			end_pos: 
		"""
		pass

	@overload
	def toReverseVector(self, end_x: float, end_y: float) -> Vec2D:
		"""
		Since: 1.6.4 

		Args:
			end_x: 
			end_y: 
		"""
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareTo(self, o: "Pos2D") -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IllagerEntityHelper import IllagerEntityHelper

net_minecraft_entity_mob_VindicatorEntity = TypeVar("net_minecraft_entity_mob_VindicatorEntity")
VindicatorEntity = net_minecraft_entity_mob_VindicatorEntity


class VindicatorEntityHelper(IllagerEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: VindicatorEntity) -> None:
		pass

	@overload
	def isJohnny(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this vindicator is johnny, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .OptionsHelper_SkinOptionsHelper import OptionsHelper_SkinOptionsHelper
from .OptionsHelper_VideoOptionsHelper import OptionsHelper_VideoOptionsHelper
from .OptionsHelper_MusicOptionsHelper import OptionsHelper_MusicOptionsHelper
from .OptionsHelper_ControlOptionsHelper import OptionsHelper_ControlOptionsHelper
from .OptionsHelper_ChatOptionsHelper import OptionsHelper_ChatOptionsHelper
from .OptionsHelper_AccessibilityOptionsHelper import OptionsHelper_AccessibilityOptionsHelper

net_minecraft_client_option_GameOptions = TypeVar("net_minecraft_client_option_GameOptions")
GameOptions = net_minecraft_client_option_GameOptions


class OptionsHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""
	skin: OptionsHelper_SkinOptionsHelper
	video: OptionsHelper_VideoOptionsHelper
	music: OptionsHelper_MusicOptionsHelper
	control: OptionsHelper_ControlOptionsHelper
	chat: OptionsHelper_ChatOptionsHelper
	accessibility: OptionsHelper_AccessibilityOptionsHelper

	@overload
	def __init__(self, options: GameOptions) -> None:
		pass

	@overload
	def getSkinOptions(self) -> OptionsHelper_SkinOptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper for the skin options. 
		"""
		pass

	@overload
	def getVideoOptions(self) -> OptionsHelper_VideoOptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper for the video options. 
		"""
		pass

	@overload
	def getMusicOptions(self) -> OptionsHelper_MusicOptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper for the music options. 
		"""
		pass

	@overload
	def getControlOptions(self) -> OptionsHelper_ControlOptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper for the control options. 
		"""
		pass

	@overload
	def getChatOptions(self) -> OptionsHelper_ChatOptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper for the chat options. 
		"""
		pass

	@overload
	def getAccessibilityOptions(self) -> OptionsHelper_AccessibilityOptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			a helper for the accessibility options. 
		"""
		pass

	@overload
	def saveOptions(self) -> "OptionsHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getResourcePacks(self) -> List[str]:
		"""
		Since: 1.1.7 

		Returns:
			list of names of resource packs. 
		"""
		pass

	@overload
	def getEnabledResourcePacks(self) -> List[str]:
		"""
		Since: 1.2.0 

		Returns:
			list of names of enabled resource packs. 
		"""
		pass

	@overload
	def setEnabledResourcePacks(self, enabled: List[str]) -> "OptionsHelper":
		"""Set the enabled resource packs to the provided list.\n
		Since: 1.2.0 

		Args:
			enabled: 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def removeServerResourcePack(self, state: bool) -> "OptionsHelper":
		"""
		Since: 1.8.3 

		Args:
			state: false to put it back 
		"""
		pass

	@overload
	def getLanguage(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the active language. 
		"""
		pass

	@overload
	def setLanguage(self, languageCode: str) -> "OptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			languageCode: the language to change to 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getDifficulty(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the active difficulty. 
		"""
		pass

	@overload
	def setDifficulty(self, name: str) -> "OptionsHelper":
		"""The name be either "peaceful", "easy", "normal", or "hard".\n
		Since: 1.8.4 

		Args:
			name: the name of the difficulty to change to 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isDifficultyLocked(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the difficulty is locked, 'false' otherwise. 
		"""
		pass

	@overload
	def lockDifficulty(self) -> "OptionsHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def unlockDifficulty(self) -> "OptionsHelper":
		"""Unlocks the difficulty of the world. This can't be done in an unmodified client.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getFov(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			the current fov value. 
		"""
		pass

	@overload
	def setFov(self, fov: int) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			fov: the new fov value 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getCameraMode(self) -> int:
		"""
		Since: 1.5.0 

		Returns:
			0 for 1st person, 2 for in front. 
		"""
		pass

	@overload
	def setCameraMode(self, mode: int) -> "OptionsHelper":
		"""
		Since: 1.5.0 

		Args:
			mode: 0: first, 2: front 
		"""
		pass

	@overload
	def getSmoothCamera(self) -> bool:
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def setSmoothCamera(self, val: bool) -> "OptionsHelper":
		"""
		Since: 1.5.0 

		Args:
			val: 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def setWidth(self, w: int) -> "OptionsHelper":
		"""
		Since: 1.2.6 

		Args:
			w: 
		"""
		pass

	@overload
	def setHeight(self, h: int) -> "OptionsHelper":
		"""
		Since: 1.2.6 

		Args:
			h: 
		"""
		pass

	@overload
	def setSize(self, w: int, h: int) -> "OptionsHelper":
		"""
		Since: 1.2.6 

		Args:
			w: 
			h: 
		"""
		pass

	@overload
	def getCloudMode(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			0: off, 2: fancy 
		"""
		pass

	@overload
	def setCloudMode(self, mode: int) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			mode: 0: off, 2: fancy 
		"""
		pass

	@overload
	def getGraphicsMode(self) -> int:
		"""
		Since: 1.1.7 
		"""
		pass

	@overload
	def setGraphicsMode(self, mode: int) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			mode: 0: fast, 2: fabulous 
		"""
		pass

	@overload
	def isRightHanded(self) -> bool:
		"""
		Since: 1.1.7 
		"""
		pass

	@overload
	def setRightHanded(self, val: bool) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			val: 
		"""
		pass

	@overload
	def getRenderDistance(self) -> int:
		"""
		Since: 1.1.7 
		"""
		pass

	@overload
	def setRenderDistance(self, d: int) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			d: 
		"""
		pass

	@overload
	def getGamma(self) -> float:
		"""
		Since: 1.3.0 normal values for gamma are between '0' and '1' 
		"""
		pass

	@overload
	def setGamma(self, gamma: float) -> "OptionsHelper":
		"""
		Since: 1.3.0 normal values for gamma are between '0' and '1' 
		"""
		pass

	@overload
	def setVolume(self, vol: float) -> "OptionsHelper":
		"""
		Since: 1.3.1 

		Args:
			vol: 
		"""
		pass

	@overload
	def setVolume(self, category: str, volume: float) -> "OptionsHelper":
		"""set volume by category.\n
		Since: 1.3.1 

		Args:
			volume: 
			category: 
		"""
		pass

	@overload
	def getVolumes(self) -> Mapping[str, Float]:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def setGuiScale(self, scale: int) -> "OptionsHelper":
		"""sets gui scale, '0' for auto.\n
		Since: 1.3.1 

		Args:
			scale: 
		"""
		pass

	@overload
	def getGuiScale(self) -> int:
		"""
		Since: 1.3.1 

		Returns:
			gui scale, '0' for auto. 
		"""
		pass

	@overload
	def getVolume(self, category: str) -> float:
		"""
		Since: 1.3.1 

		Args:
			category: 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .BaseHelper import BaseHelper
from .NBTElementHelper_NBTNumberHelper import NBTElementHelper_NBTNumberHelper
from .NBTElementHelper_NBTListHelper import NBTElementHelper_NBTListHelper
from .NBTElementHelper_NBTCompoundHelper import NBTElementHelper_NBTCompoundHelper

T = TypeVar("T")
net_minecraft_nbt_NbtCompound = TypeVar("net_minecraft_nbt_NbtCompound")
NbtCompound = net_minecraft_nbt_NbtCompound

net_minecraft_nbt_NbtElement = TypeVar("net_minecraft_nbt_NbtElement")
NbtElement = net_minecraft_nbt_NbtElement


class NBTElementHelper(Generic[T], BaseHelper):
	"""
	Since: 1.5.1 
	"""

	@overload
	def getType(self) -> int:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def resolve(self, nbtPath: str) -> List["NBTElementHelper"]:
		"""resolves the nbt path to elements, or null if not found.  NBT path format wiki\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def isNull(self) -> bool:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def isNumber(self) -> bool:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def isString(self) -> bool:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def isList(self) -> bool:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def isCompound(self) -> bool:
		"""
		Since: 1.5.1 
		"""
		pass

	@overload
	def asString(self) -> str:
		"""if element is a string, returns value.
otherwise returns toString representation.\n
		Since: 1.5.1 
		"""
		pass

	@overload
	def asNumberHelper(self) -> NBTElementHelper_NBTNumberHelper:
		"""check with NBTElementHelper#isNumber() first\n
		Since: 1.5.1 
		"""
		pass

	@overload
	def asListHelper(self) -> NBTElementHelper_NBTListHelper:
		"""check with NBTElementHelper#isList() first\n
		Since: 1.5.1 
		"""
		pass

	@overload
	def asCompoundHelper(self) -> NBTElementHelper_NBTCompoundHelper:
		"""check with NBTElementHelper#isCompound() first\n
		Since: 1.5.1 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def wrapCompound(self, compound: NbtCompound) -> NBTElementHelper_NBTCompoundHelper:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def wrap(self, element: NbtElement) -> "NBTElementHelper":
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def resolve(self, element: NbtElement) -> "NBTElementHelper":
		"""
		Since: 1.5.1 
		"""
		pass

	pass





from typing import overload
from .BaseListener import BaseListener
from .ScriptTrigger import ScriptTrigger
from .Core import Core
from .BaseEvent import BaseEvent
from .EventContainer import EventContainer


class EventListener(BaseListener):

	@overload
	def __init__(self, macro: ScriptTrigger, runner: Core) -> None:
		pass

	@overload
	def trigger(self, event: BaseEvent) -> EventContainer:
		pass

	pass





from typing import overload
from .Alignable import Alignable
from .RenderElementBuilder import RenderElementBuilder
from .IDraw2D import IDraw2D


class Line_Builder(Alignable, RenderElementBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, draw2D: IDraw2D) -> None:
		pass

	@overload
	def x1(self, x1: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			x1: the x position of the first point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX1(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the first point. 
		"""
		pass

	@overload
	def y1(self, y1: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			y1: the y position of the first point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY1(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the first point. 
		"""
		pass

	@overload
	def pos1(self, x1: int, y1: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			y1: the y position of the first point 
			x1: the x position of the first point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def x2(self, x2: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			x2: the x position of the second point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX2(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the second point. 
		"""
		pass

	@overload
	def y2(self, y2: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			y2: the y position of the second point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY2(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the second point. 
		"""
		pass

	@overload
	def pos2(self, x2: int, y2: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			y2: the y position of the second point 
			x2: the x position of the second point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def pos(self, x1: int, y1: int, x2: int, y2: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			y1: the y position of the first point 
			x1: the x position of the first point 
			y2: the y position of the second point 
			x2: the x position of the second point 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def rotation(self, rotation: float) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotation: the rotation (clockwise) of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation (clockwise) of the line. 
		"""
		pass

	@overload
	def rotateCenter(self, rotateCenter: bool) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether this line should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this line should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def width(self, width: float) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the width of the line. 
		"""
		pass

	@overload
	def color(self, color: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, color: int, alpha: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the line 
			alpha: the alpha component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int, a: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			a: the alpha value of the color 
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of the line. 
		"""
		pass

	@overload
	def alpha(self, alpha: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			alpha: the alpha value of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of the color. 
		"""
		pass

	@overload
	def zIndex(self, zIndex: int) -> "Line_Builder":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the z-index of the line 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the z-index of the line. 
		"""
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Line_Builder":
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_client_gui_widget_TextFieldWidget = TypeVar("net_minecraft_client_gui_widget_TextFieldWidget")
TextFieldWidget = net_minecraft_client_gui_widget_TextFieldWidget


class MixinAnvilScreen:
	"""
	Since: 1.8.4 
	"""

	@overload
	def getNameField(self) -> TextFieldWidget:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_OcelotEntity = TypeVar("net_minecraft_entity_passive_OcelotEntity")
OcelotEntity = net_minecraft_entity_passive_OcelotEntity


class OcelotEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: OcelotEntity) -> None:
		pass

	@overload
	def isTrusting(self) -> bool:
		"""Ocelots trust players after being fed with cod or salmon.\n
		Since: 1.8.4 

		Returns:
			'true' if this ocelot is trusting player and not running away form them, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from .ClassWrapperFilter import ClassWrapperFilter


class BlockStateFilter(ClassWrapperFilter):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, methodName: str, methodArgs: List[object], filterArgs: List[object]) -> None:
		pass

	pass





from typing import overload
from typing import List
from .Inventory import Inventory
from .TextHelper import TextHelper
from .EnchantmentHelper import EnchantmentHelper
from .ItemStackHelper import ItemStackHelper


class EnchantInventory(Inventory):
	"""
	Since: 1.3.1 
	"""

	@overload
	def getRequiredLevels(self) -> List[int]:
		"""
		Since: 1.3.1 

		Returns:
			xp level required to do enchantments 
		"""
		pass

	@overload
	def getEnchantments(self) -> List[TextHelper]:
		"""
		Since: 1.3.1 

		Returns:
			list of enchantments text. 
		"""
		pass

	@overload
	def getEnchantmentHelpers(self) -> List[EnchantmentHelper]:
		"""
		Since: 1.8.4 

		Returns:
			the visible enchantment for each level. 
		"""
		pass

	@overload
	def getEnchantmentIds(self) -> List[str]:
		"""
		Since: 1.3.1 

		Returns:
			id for enchantments 
		"""
		pass

	@overload
	def getEnchantmentLevels(self) -> List[int]:
		"""
		Since: 1.3.1 

		Returns:
			level of enchantments 
		"""
		pass

	@overload
	def doEnchant(self, index: int) -> bool:
		"""clicks the button to enchant.\n
		Since: 1.3.1 

		Args:
			index: 

		Returns:
			success 
		"""
		pass

	@overload
	def getItemToEnchant(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the item to be enchanted. 
		"""
		pass

	@overload
	def getLapis(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the slot containing the lapis lazuli. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar

net_minecraft_predicate_BlockPredicate = TypeVar("net_minecraft_predicate_BlockPredicate")
BlockPredicate = net_minecraft_predicate_BlockPredicate


class MixinBlockPredicatesChecker:

	@overload
	def getPredicates(self) -> List[BlockPredicate]:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AbstractPiglinEntityHelper import AbstractPiglinEntityHelper

net_minecraft_entity_mob_PiglinEntity = TypeVar("net_minecraft_entity_mob_PiglinEntity")
PiglinEntity = net_minecraft_entity_mob_PiglinEntity


class PiglinEntityHelper(AbstractPiglinEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: PiglinEntity) -> None:
		pass

	@overload
	def isWandering(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this piglin is doing nothing special, 'false' otherwise. 
		"""
		pass

	@overload
	def isDancing(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this piglin is dancing to music, 'false' otherwise. 
		"""
		pass

	@overload
	def isAdmiring(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this piglin is admiring an item, 'false' otherwise. 
		"""
		pass

	@overload
	def isMeleeAttacking(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this piglin is attacking another entity, 'false' otherwise. 
		"""
		pass

	@overload
	def isChargingCrossbow(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this piglin is currently charging its crossbow, 'false' otherwise. 
		"""
		pass

	@overload
	def hasCrossbowReady(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this piglin has its crossbow fully charged, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar

net_minecraft_client_gui_hud_ChatHudLine = TypeVar("net_minecraft_client_gui_hud_ChatHudLine")
ChatHudLine = net_minecraft_client_gui_hud_ChatHudLine

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

java_util_function_Predicate_net_minecraft_client_gui_hud_ChatHudLine_ = TypeVar("java_util_function_Predicate_net_minecraft_client_gui_hud_ChatHudLine_")
Predicate = java_util_function_Predicate_net_minecraft_client_gui_hud_ChatHudLine_


class IChatHud:

	@overload
	def jsmacros_addMessageBypass(self, message: Text) -> None:
		pass

	@overload
	def jsmacros_getMessages(self) -> List[ChatHudLine]:
		pass

	@overload
	def jsmacros_removeMessageById(self, messageId: int) -> None:
		pass

	@overload
	def jsmacros_addMessageAtIndexBypass(self, message: Text, index: int, time: int) -> None:
		pass

	@overload
	def jsmacros_removeMessage(self, index: int) -> None:
		pass

	@overload
	def jsmacros_removeMessageByText(self, text: Text) -> None:
		pass

	@overload
	def jsmacros_removeMessagePredicate(self, textfilter: Predicate) -> None:
		pass

	pass





from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .MixinAbstractFurnaceScreenHandler import MixinAbstractFurnaceScreenHandler
from .MixinRecipeBookWidget import MixinRecipeBookWidget
from .MixinFontManager import MixinFontManager
from .MixinChunkSelection import MixinChunkSelection
from .MixinLivingEntity import MixinLivingEntity
from .MixinClientConnection import MixinClientConnection
from .MixinMinecraftClient import MixinMinecraftClient
from .MixinInteractionEntity2 import MixinInteractionEntity2
from .MixinClientPlayNetworkHandler import MixinClientPlayNetworkHandler
from .MixinMerchantEntity import MixinMerchantEntity
from .MixinDisconnectedScreen import MixinDisconnectedScreen
from .MixinShulkerEntity import MixinShulkerEntity
from .MixinSplashOverlay import MixinSplashOverlay
from .MixinTrueTypeFont import MixinTrueTypeFont
from .MixinClientPlayerInteractionManager import MixinClientPlayerInteractionManager
from .MixinCreativeInventoryScreen import MixinCreativeInventoryScreen
from .MixinChatHud import MixinChatHud
from .MixinHandledScreen import MixinHandledScreen
from .MixinItemCooldownManager import MixinItemCooldownManager
from .MixinDisplayEntity import MixinDisplayEntity
from .MixinSoundSystem import MixinSoundSystem
from .MixinWorldRenderer import MixinWorldRenderer
from .MixinTranslationStorage import MixinTranslationStorage
from .MixinPlayerListHud import MixinPlayerListHud
from .MixinAbstractHorseEntity import MixinAbstractHorseEntity
from .MixinFishingBobberEntity import MixinFishingBobberEntity
from .MixinFontStorage import MixinFontStorage
from .IMixinInteractionEntity import IMixinInteractionEntity
from .MixinBossBarHud import MixinBossBarHud
from .MixinPlayerEntity import MixinPlayerEntity
from .MixinRecipeBookResults import MixinRecipeBookResults
from .MixinTridentEntity import MixinTridentEntity
from .MixinCreeperEntity import MixinCreeperEntity
from .MixinStyleSerializer import MixinStyleSerializer
from .MixinOcelotEntity import MixinOcelotEntity
from .MixinScreen import MixinScreen
from .MixinAllayEntity import MixinAllayEntity
from .MixinSignEditScreen import MixinSignEditScreen
from .MixinHungerManager import MixinHungerManager
from .MixinBoatEntity import MixinBoatEntity
from .MixinAdvancementManager import MixinAdvancementManager
from .MixinInteractionEntity import MixinInteractionEntity
from .IMixinEntity import IMixinEntity
from .MixinItemEnchantmentsComponent import MixinItemEnchantmentsComponent
from .MixinBlockPredicatesChecker import MixinBlockPredicatesChecker
from .MixinPackedIntegerArray import MixinPackedIntegerArray
from .MixinClientAdvancementManager import MixinClientAdvancementManager
from .MixinPhaseType import MixinPhaseType
from .MixinAbstractPiglinEntity import MixinAbstractPiglinEntity
from .MixinHorseScreen import MixinHorseScreen
from .MixinPalettedContainer import MixinPalettedContainer
from .MixinChatScreen import MixinChatScreen
from .MixinEntity2 import MixinEntity2
from .MixinLoomScreen import MixinLoomScreen
from .MixinSimpleOption import MixinSimpleOption
from .MixinResourcePackManager import MixinResourcePackManager
from .MixinClientWorld import MixinClientWorld
from .MixinDataTracker import MixinDataTracker
from .MixinTextFieldWidget import MixinTextFieldWidget
from .MixinBeaconScreen import MixinBeaconScreen
from .MixinItemCooldownEntry import MixinItemCooldownEntry
from .MixinEntity import MixinEntity
from .MixinFoxEntity import MixinFoxEntity
from .MixinAnvilScreen import MixinAnvilScreen
from .MixinMerchantScreen import MixinMerchantScreen
from .MixinHorseEntity import MixinHorseEntity
from .MixinCyclingButton import MixinCyclingButton
from .MixinStatHandler import MixinStatHandler
from .MixinMessageHandler import MixinMessageHandler
from .MixinAdvancementProgress import MixinAdvancementProgress
from .MixinPalettedContainerData import MixinPalettedContainerData

File = TypeVar("java.io.File")




from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .EntityHelper import EntityHelper
from .StatusEffectHelper import StatusEffectHelper
from .ItemStackHelper import ItemStackHelper

T = TypeVar("T")

class LivingEntityHelper(Generic[T], EntityHelper):

	@overload
	def __init__(self, e: T) -> None:
		pass

	@overload
	def getStatusEffects(self) -> List[StatusEffectHelper]:
		"""
		Since: 1.2.7 

		Returns:
			entity status effects. 
		"""
		pass

	@overload
	def canHaveStatusEffect(self, effect: StatusEffectHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			effect: the status effect 

		Returns:
			if the entity can have a certain status effect 
		"""
		pass

	@overload
	def hasStatusEffect(self, id: str) -> bool:
		"""For client side entities, excluding the player, this will most likely return 'false' even if the entity has the effect, as effects are not synced to the client.\n
		Since: 1.8.4 

		Returns:
			'true' if the entity has the specified status effect, 'false' otherwise. 
		"""
		pass

	@overload
	def isHolding(self, item: str) -> bool:
		"""
		Since: 1.9.0 

		Returns:
			'true' if the entity is holding the specified item 
		"""
		pass

	@overload
	def getMainHand(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's main hand. 
		"""
		pass

	@overload
	def getOffHand(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's off hand. 
		"""
		pass

	@overload
	def getHeadArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's head armor slot. 
		"""
		pass

	@overload
	def getChestArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's chest armor slot. 
		"""
		pass

	@overload
	def getLegArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's leg armor slot. 
		"""
		pass

	@overload
	def getFootArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's foot armor slot. 
		"""
		pass

	@overload
	def getHealth(self) -> float:
		"""
		Since: 1.3.1 

		Returns:
			entity's health 
		"""
		pass

	@overload
	def getMaxHealth(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			entity's max health 
		"""
		pass

	@overload
	def getAbsorptionHealth(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the entity's absorption amount. 
		"""
		pass

	@overload
	def getArmor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the entity's armor value. 
		"""
		pass

	@overload
	def getDefaultHealth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the entity's default health. 
		"""
		pass

	@overload
	def getMobTags(self) -> List[str]:
		"""
		Since: 1.9.1 
		"""
		pass

	@overload
	def isSleeping(self) -> bool:
		"""
		Since: 1.2.7 

		Returns:
			if the entity is in a bed. 
		"""
		pass

	@overload
	def isFallFlying(self) -> bool:
		"""
		Since: 1.5.0 

		Returns:
			if the entity has elytra deployed 
		"""
		pass

	@overload
	def isOnGround(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity is on the ground 
		"""
		pass

	@overload
	def canBreatheInWater(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity can breathe in water 
		"""
		pass

	@overload
	def hasNoDrag(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity has no drag 
		"""
		pass

	@overload
	def hasNoGravity(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity has no gravity 
		"""
		pass

	@overload
	def canTarget(self, target: "LivingEntityHelper") -> bool:
		"""
		Since: 1.8.4 

		Args:
			target: the target entity 

		Returns:
			if the entity can target a target entity 
		"""
		pass

	@overload
	def canTakeDamage(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity can take damage 
		"""
		pass

	@overload
	def isPartOfGame(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity is part of the game (is alive and not spectator) 
		"""
		pass

	@overload
	def isSpectator(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity is in spectator 
		"""
		pass

	@overload
	def isUndead(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			if the entity is undead 
		"""
		pass

	@overload
	def getBowPullProgress(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the bow pull progress of the entity, '0' by default. 
		"""
		pass

	@overload
	def getItemUseTimeLeft(self) -> int:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def isBaby(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if the entity is a baby, 'false' otherwise. 
		"""
		pass

	@overload
	def canSeeEntity(self, entity: EntityHelper) -> bool:
		"""
		Since: 1.8.4 

		Args:
			entity: the entity to check line of sight to 

		Returns:
			'true' if the player has line of sight to the specified entity, 'false' otherwise. 
		"""
		pass

	@overload
	def canSeeEntity(self, entity: EntityHelper, simpleCast: bool) -> bool:
		"""
		Since: 1.8.4 

		Args:
			simpleCast: whether to use a simple raycast or a more complex one 
			entity: the entity to check line of sight to 

		Returns:
			'true' if the entity has line of sight to the specified entity, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .IBeaconScreen import IBeaconScreen

net_minecraft_registry_entry_RegistryEntry_net_minecraft_entity_effect_StatusEffect_ = TypeVar("net_minecraft_registry_entry_RegistryEntry_net_minecraft_entity_effect_StatusEffect_")
RegistryEntry = net_minecraft_registry_entry_RegistryEntry_net_minecraft_entity_effect_StatusEffect_


class MixinBeaconScreen(IBeaconScreen):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getPrimaryEffect(self) -> RegistryEntry:
		pass

	@overload
	def jsmacros_setPrimaryEffect(self, effect: RegistryEntry) -> None:
		pass

	@overload
	def jsmacros_getSecondaryEffect(self) -> RegistryEntry:
		pass

	@overload
	def jsmacros_setSecondaryEffect(self, effect: RegistryEntry) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .Inventory import Inventory

T = TypeVar("T")

class ContainerInventory(Generic[T], Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: T) -> None:
		pass

	@overload
	def findFreeContainerSlot(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the first free slot in this container. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper

net_minecraft_entity_vehicle_FurnaceMinecartEntity = TypeVar("net_minecraft_entity_vehicle_FurnaceMinecartEntity")
FurnaceMinecartEntity = net_minecraft_entity_vehicle_FurnaceMinecartEntity


class FurnaceMinecartEntityHelper(EntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: FurnaceMinecartEntity) -> None:
		pass

	@overload
	def isPowered(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'' true if the furnace minecart is powered, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .ScriptTrigger import ScriptTrigger

java_io_File = TypeVar("java_io_File")
File = java_io_File


class ServiceTrigger:
	file: str
	enabled: bool

	@overload
	def __init__(self, file: File, enabled: bool) -> None:
		pass

	@overload
	def toScriptTrigger(self) -> ScriptTrigger:
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IMixinEntity import IMixinEntity

org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_ = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_")
CallbackInfoReturnable = org_spongepowered_asm_mixin_injection_callback_CallbackInfoReturnable_java_lang_Boolean_


class MixinEntity(IMixinEntity):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_setGlowingColor(self, glowingColor: int) -> None:
		pass

	@overload
	def jsmacros_resetColor(self) -> None:
		pass

	@overload
	def getTeamColorValue(self, ci: CallbackInfoReturnable) -> None:
		pass

	@overload
	def jsmacros_setForceGlowing(self, glowing: int) -> None:
		pass

	@overload
	def isGlowing(self, cir: CallbackInfoReturnable) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .ClientPlayerEntityHelper import ClientPlayerEntityHelper

net_minecraft_client_network_ClientPlayerEntity = TypeVar("net_minecraft_client_network_ClientPlayerEntity")
ClientPlayerEntity = net_minecraft_client_network_ClientPlayerEntity


class EventJoinServer(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	player: ClientPlayerEntityHelper
	address: str

	@overload
	def __init__(self, player: ClientPlayerEntity, address: str) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderElement3D import RenderElement3D
from .Pos2D import Pos2D
from .Pos3D import Pos3D

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_client_render_BufferBuilder = TypeVar("net_minecraft_client_render_BufferBuilder")
BufferBuilder = net_minecraft_client_render_BufferBuilder


class TraceLine(RenderElement3D):
	"""
	Since: 1.9.0 
	"""
	screenPos: Pos2D
	pos: Pos3D
	color: int

	@overload
	def __init__(self, x: float, y: float, z: float, color: int) -> None:
		pass

	@overload
	def __init__(self, x: float, y: float, z: float, color: int, alpha: int) -> None:
		pass

	@overload
	def __init__(self, pos: Pos3D, color: int) -> None:
		pass

	@overload
	def __init__(self, pos: Pos3D, color: int, alpha: int) -> None:
		pass

	@overload
	def setPos(self, x: float, y: float, z: float) -> "TraceLine":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setPos(self, pos: Pos3D) -> "TraceLine":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setColor(self, color: int) -> "TraceLine":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> "TraceLine":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def setAlpha(self, alpha: int) -> "TraceLine":
		"""
		Since: 1.9.0 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def equals(self, o: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def compareToSame(self, other: "TraceLine") -> int:
		pass

	@overload
	def render(self, drawContext: DrawContext, builder: BufferBuilder, tickDelta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

net_minecraft_util_DyeColor = TypeVar("net_minecraft_util_DyeColor")
DyeColor = net_minecraft_util_DyeColor


class DyeColorHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: DyeColor) -> None:
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the name of the color. 
		"""
		pass

	@overload
	def getId(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color's identifier. 
		"""
		pass

	@overload
	def getColorValue(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color's rgb value. 
		"""
		pass

	@overload
	def getFireworkColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color's variation when used in fireworks. 
		"""
		pass

	@overload
	def getSignColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color's variation when used on signs. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .MethodWrapper import MethodWrapper
from .BlockPosHelper import BlockPosHelper
from .ChunkHelper import ChunkHelper
from .NBTElementHelper_NBTCompoundHelper import NBTElementHelper_NBTCompoundHelper
from .NBTElementHelper import NBTElementHelper
from .HitResultHelper_Block import HitResultHelper_Block
from .Pos3D import Pos3D

java_util_function_Function_net_minecraft_network_PacketByteBuf, extends net_minecraft_network_packet_Packet___ = TypeVar("java_util_function_Function_net_minecraft_network_PacketByteBuf, extends net_minecraft_network_packet_Packet___")
Function = java_util_function_Function_net_minecraft_network_PacketByteBuf, extends net_minecraft_network_packet_Packet___

net_minecraft_network_packet_Packet__ = TypeVar("net_minecraft_network_packet_Packet__")
Packet = net_minecraft_network_packet_Packet__

T = TypeVar("T")
java_util_Optional_T_ = TypeVar("java_util_Optional_T_")
Optional = java_util_Optional_T_

V = TypeVar("V")
V = V

net_minecraft_network_PacketByteBuf = TypeVar("net_minecraft_network_PacketByteBuf")
PacketByteBuf = net_minecraft_network_PacketByteBuf

java_util_BitSet = TypeVar("java_util_BitSet")
BitSet = java_util_BitSet

K = TypeVar("K")
K = K

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID

net_minecraft_util_hit_BlockHitResult = TypeVar("net_minecraft_util_hit_BlockHitResult")
BlockHitResult = net_minecraft_util_hit_BlockHitResult

net_minecraft_registry_RegistryKey_T_ = TypeVar("net_minecraft_registry_RegistryKey_T_")
RegistryKey = net_minecraft_registry_RegistryKey_T_

java_util_Date = TypeVar("java_util_Date")
Date = java_util_Date


class PacketByteBufferHelper(BaseHelper):
	"""
	Since: 1.8.4 
	"""
	BUFFER_TO_PACKET: Mapping[Class, Function]

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def __init__(self, base: PacketByteBuf) -> None:
		pass

	@overload
	def __init__(self, packet: Packet) -> None:
		pass

	@overload
	def toPacket(self) -> Packet:
		"""
		Since: 1.8.4 

		Returns:
			the packet for this buffer or 'null' if no packet was used to create this
helper. 
		"""
		pass

	@overload
	def toPacket(self, packetName: str) -> Packet:
		"""
		Since: 1.8.4 

		Args:
			packetName: the name of the packet's class that should be returned 

		Returns:
			the packet for this buffer. 
		"""
		pass

	@overload
	def toPacket(self, clazz: Class) -> Packet:
		"""
		Since: 1.8.4 

		Args:
			clazz: the class of the packet to return 

		Returns:
			the packet for this buffer. 
		"""
		pass

	@overload
	def getPacketId(self, packetClass: Class) -> int:
		"""
		Since: 1.8.4 

		Args:
			packetClass: the class of the packet to get the id for 

		Returns:
			the id of the packet. 
		"""
		pass

	@overload
	def getNetworkStateId(self, packetClass: Class) -> int:
		"""
		Since: 1.8.4 

		Args:
			packetClass: the class of the packet to get the id for 

		Returns:
			the id of the network state the packet belongs to. 
		"""
		pass

	@overload
	def isClientbound(self, packetClass: Class) -> bool:
		"""
		Since: 1.8.4 

		Args:
			packetClass: the class to get the side for 

		Returns:
			'true' if the packet is clientbound, 'false' if it is serverbound. 
		"""
		pass

	@overload
	def isServerbound(self, packetClass: Class) -> bool:
		"""
		Since: 1.8.4 

		Args:
			packetClass: the class to get the id for 

		Returns:
			'true' if the packet is serverbound, 'false' if it is clientbound. 
		"""
		pass

	@overload
	def sendPacket(self) -> "PacketByteBufferHelper":
		"""Send a packet of the given type, created from this buffer, to the server.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def sendPacket(self, packetName: str) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			packetName: the name of the packet's class that should be sent 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def sendPacket(self, clazz: Class) -> "PacketByteBufferHelper":
		"""Send a packet of the given type, created from this buffer, to the server.\n
		Since: 1.8.4 

		Args:
			clazz: the class of the packet to send 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def receivePacket(self) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def receivePacket(self, packetName: str) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			packetName: the name of the packet's class that should be received 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def receivePacket(self, clazz: Class) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			clazz: the class of the packet to receive 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getPacketNames(self) -> List[str]:
		"""These names are subject to change and are only for an easier access. They will probably not
change in the future, but it is not guaranteed.\n
		Since: 1.8.4 

		Returns:
			a list of all packet names. 
		"""
		pass

	@overload
	def reset(self) -> "PacketByteBufferHelper":
		"""Resets the buffer to the state it was in when this helper was created.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeRegistryKey(self, key: RegistryKey) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			key: the registry key to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readRegistryKey(self, registry: RegistryKey) -> RegistryKey:
		"""
		Since: 1.8.4 

		Args:
			registry: the registry the read key is from 

		Returns:
			the registry key. 
		"""
		pass

	@overload
	def writeCollection(self, collection: List[T], writer: MethodWrapper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			collection: the collection to store 
			writer: the function that writes the collection's elements to the buffer 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readList(self, reader: MethodWrapper) -> List[T]:
		"""
		Since: 1.8.4 

		Args:
			reader: the function that reads the collection's elements from the buffer 

		Returns:
			the read list. 
		"""
		pass

	@overload
	def writeIntList(self, list: List[int]) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			list: the integer list to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readIntList(self) -> IntList:
		"""
		Since: 1.8.4 

		Returns:
			the read integer list. 
		"""
		pass

	@overload
	def writeMap(self, map: Mapping[K, V], keyWriter: MethodWrapper, valueWriter: MethodWrapper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			keyWriter: the function to write the map's keys to the buffer 
			map: the map to store 
			valueWriter: the function to write the map's values to the buffer 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readMap(self, keyReader: MethodWrapper, valueReader: MethodWrapper) -> Mapping[K, V]:
		"""
		Since: 1.8.4 

		Args:
			valueReader: the function to read the map's values from the buffer 
			keyReader: the function to read the map's keys from the buffer 

		Returns:
			the read map. 
		"""
		pass

	@overload
	def forEachInCollection(self, reader: MethodWrapper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			reader: the function to read the collection's elements from the buffer 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeOptional(self, value: T, writer: MethodWrapper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			writer: the function to write the optional value if present to the buffer 
			value: the optional value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readOptional(self, reader: MethodWrapper) -> Optional:
		"""
		Since: 1.8.4 

		Args:
			reader: the function to read the optional value from the buffer if present 

		Returns:
			the optional value. 
		"""
		pass

	@overload
	def writeNullable(self, value: object, writer: MethodWrapper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			writer: the function to write the optional value if it's not null to the buffer 
			value: the optional value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readNullable(self, reader: MethodWrapper) -> T:
		"""
		Since: 1.8.4 

		Args:
			reader: the function to read the value from the buffer if it's not null 

		Returns:
			the read value or 'null' if it was null. 
		"""
		pass

	@overload
	def writeByteArray(self, bytes: List[float]) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			bytes: the bytes to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readByteArray(self) -> List[float]:
		"""
		Since: 1.8.4 

		Returns:
			the read byte array. 
		"""
		pass

	@overload
	def readByteArray(self, maxSize: int) -> List[float]:
		"""Will throw an exception if the byte array is bigger than the given maximum size.\n
		Since: 1.8.4 

		Args:
			maxSize: the maximum size of the byte array to read 

		Returns:
			the read byte array. 
		"""
		pass

	@overload
	def writeIntArray(self, ints: List[int]) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			ints: the int array to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readIntArray(self) -> List[int]:
		"""
		Since: 1.8.4 

		Returns:
			the read int array. 
		"""
		pass

	@overload
	def readIntArray(self, maxSize: int) -> "PacketByteBufferHelper":
		"""Will throw an exception if the int array is bigger than the given maximum size.\n
		Since: 1.8.4 

		Args:
			maxSize: the maximum size of the int array to read 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeLongArray(self, longs: List[float]) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			longs: the long array to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readLongArray(self) -> List[float]:
		"""
		Since: 1.8.4 

		Returns:
			the read long array. 
		"""
		pass

	@overload
	def readLongArray(self, maxSize: int) -> List[float]:
		"""Will throw an exception if the long array is bigger than the given maximum size.\n
		Since: 1.8.4 

		Args:
			maxSize: the maximum size of the long array to read 

		Returns:
			the read long array. 
		"""
		pass

	@overload
	def writeBlockPos(self, pos: BlockPosHelper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			pos: the block position to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeBlockPos(self, x: int, y: int, z: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate of the block position to store 
			y: the y coordinate of the block position to store 
			z: the z coordinate of the block position to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readBlockPos(self) -> BlockPosHelper:
		"""
		Since: 1.8.4 

		Returns:
			the read block position. 
		"""
		pass

	@overload
	def writeChunkPos(self, x: int, z: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate of the chunk to store 
			z: the z coordinate of the chunk to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeChunkPos(self, chunk: ChunkHelper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			chunk: the chunk to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readChunkPos(self) -> List[int]:
		"""
		Since: 1.8.4 

		Returns:
			the position of the read chunk, x at index 0, z at index 1. 
		"""
		pass

	@overload
	def readChunkHelper(self) -> ChunkHelper:
		"""
		Since: 1.8.4 

		Returns:
			a ChunkHelper for the read chunk position. 
		"""
		pass

	@overload
	def writeChunkSectionPos(self, chunkX: int, y: int, chunkZ: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			y: the y coordinate to store 
			chunkX: the x coordinate of the chunk to store 
			chunkZ: the z coordinate of the chunk to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeChunkSectionPos(self, chunk: ChunkHelper, y: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			chunk: the chunk whose position should be stored 
			y: the y to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readChunkSectionPos(self) -> BlockPosHelper:
		"""
		Since: 1.8.4 

		Returns:
			the read chunk section pos, as a BlockPosHelper . 
		"""
		pass

	@overload
	def writeGlobalPos(self, dimension: str, pos: BlockPosHelper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			pos: the position to store 
			dimension: the dimension, vanilla default are 'overworld' , 'the_nether' , 'the_end' 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeGlobalPos(self, dimension: str, x: int, y: int, z: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate of the position to store 
			y: the y coordinate of the position to store 
			z: the z coordinate of the position to store 
			dimension: the dimension, vanilla default are 'overworld' , 'the_nether' , 'the_end' 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeEnumConstant(self, constant: ) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			constant: the enum constant to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readEnumConstant(self, enumClass: Class) -> T:
		"""
		Since: 1.8.4 

		Args:
			enumClass: the class of the enum to read from 

		Returns:
			the read enum constant. 
		"""
		pass

	@overload
	def writeVarInt(self, i: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			i: the int to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readVarInt(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the read int. 
		"""
		pass

	@overload
	def writeVarLong(self, l: float) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			l: the long to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readVarLong(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read long. 
		"""
		pass

	@overload
	def writeUuid(self, uuid: str) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			uuid: the UUID to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readUuid(self) -> UUID:
		"""
		Since: 1.8.4 

		Returns:
			the read UUID. 
		"""
		pass

	@overload
	def writeNbt(self, nbt: NBTElementHelper_NBTCompoundHelper) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			nbt: the nbt 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readNbt(self) -> NBTElementHelper:
		"""
		Since: 1.8.4 

		Returns:
			the read nbt data. 
		"""
		pass

	@overload
	def writeString(self, string: str) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			string: the string to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeString(self, string: str, maxLength: int) -> "PacketByteBufferHelper":
		"""Throws an exception if the string is longer than the given length.\n
		Since: 1.8.4 

		Args:
			string: the string to store 
			maxLength: the maximum length of the string 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readString(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the read string. 
		"""
		pass

	@overload
	def readString(self, maxLength: int) -> str:
		"""Throws an exception if the read string is longer than the given length.\n
		Since: 1.8.4 

		Args:
			maxLength: the maximum length of the string to read 

		Returns:
			the read string. 
		"""
		pass

	@overload
	def writeIdentifier(self, id: str) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			id: the identifier to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readIdentifier(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the read identifier. 
		"""
		pass

	@overload
	def writeDate(self, date: Date) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			date: the date to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readDate(self) -> Date:
		"""
		Since: 1.8.4 

		Returns:
			the read date. 
		"""
		pass

	@overload
	def writeInstant(self, instant: Instant) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			instant: the instant to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readInstant(self) -> Instant:
		"""
		Since: 1.8.4 

		Returns:
			the read instant. 
		"""
		pass

	@overload
	def writePublicKey(self, key: PublicKey) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			key: the public key to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readPublicKey(self) -> PublicKey:
		"""
		Since: 1.8.4 

		Returns:
			the read public key. 
		"""
		pass

	@overload
	def writeBlockHitResult(self, hitResult: BlockHitResult) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			hitResult: the hit result to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeBlockHitResult(self, hitResult: HitResultHelper_Block) -> "PacketByteBufferHelper":
		"""
		Since: 1.9.1 

		Args:
			hitResult: the hit result to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeBlockHitResult(self, pos: Pos3D, direction: str, blockPos: BlockPosHelper, missed: bool, insideBlock: bool) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			insideBlock: whether the BlockHitResult is inside a block 
			blockPos: the block pos of the BlockHitResult 
			pos: the position of the BlockHitResult 
			missed: whether the BlockHitResult missed 
			direction: the direction of the BlockHitResult 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readBlockHitResult(self) -> BlockHitResult:
		"""
		Since: 1.8.4 

		Returns:
			the read block hit result. 
		"""
		pass

	@overload
	def readBlockHitResultMap(self) -> Mapping[str, object]:
		"""
		Since: 1.8.4 

		Returns:
			a map of the block hit result's data and their values. 
		"""
		pass

	@overload
	def readBlockHitResultHelper(self) -> HitResultHelper_Block:
		"""
		Since: 1.9.1 

		Returns:
			the read block hit result as a helper. 
		"""
		pass

	@overload
	def writeBitSet(self, bitSet: BitSet) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			bitSet: the bit set to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readBitSet(self) -> BitSet:
		"""
		Since: 1.8.4 

		Returns:
			the read bit set. 
		"""
		pass

	@overload
	def readerIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the readers current position. 
		"""
		pass

	@overload
	def setReaderIndex(self, index: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the readers new index 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writerIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the writers current position. 
		"""
		pass

	@overload
	def setWriterIndex(self, index: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the writers new index 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setIndices(self, readerIndex: int, writerIndex: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			readerIndex: the readers new index 
			writerIndex: the writers new index 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def resetIndices(self) -> "PacketByteBufferHelper":
		"""Resets the readers and writers index to their respective last marked indices.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def markReaderIndex(self) -> "PacketByteBufferHelper":
		"""Marks the readers current index for later use.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def resetReaderIndex(self) -> "PacketByteBufferHelper":
		"""Resets the readers index to the last marked index.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def markWriterIndex(self) -> "PacketByteBufferHelper":
		"""Marks the writers current index for later use.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def resetWriterIndex(self) -> "PacketByteBufferHelper":
		"""Resets the writers index to the last marked index.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def clear(self) -> "PacketByteBufferHelper":
		"""Resets the writers and readers index to 0. This technically doesn't clear the buffer, but
rather makes it so that new operations will overwrite the old data.\n
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeBoolean(self, value: bool) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setBoolean(self, index: int, value: bool) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readBoolean(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			the read boolean value. 
		"""
		pass

	@overload
	def getBoolean(self, index: int) -> bool:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the boolean value at the given index. 
		"""
		pass

	@overload
	def writeChar(self, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setChar(self, index: int, value: str) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readChar(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the read char value. 
		"""
		pass

	@overload
	def getChar(self, index: int) -> str:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the char at the given index. 
		"""
		pass

	@overload
	def writeByte(self, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setByte(self, index: int, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readByte(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read byte value. 
		"""
		pass

	@overload
	def readUnsignedByte(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read unsigned byte value, represented as a short. 
		"""
		pass

	@overload
	def getByte(self, index: int) -> float:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the byte at the given index. 
		"""
		pass

	@overload
	def getUnsignedByte(self, index: int) -> float:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the unsigned byte at the given index, represented as a short. 
		"""
		pass

	@overload
	def writeShort(self, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setShort(self, index: int, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readShort(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read short value. 
		"""
		pass

	@overload
	def readUnsignedShort(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the read unsigned short value, represented as an int. 
		"""
		pass

	@overload
	def getShort(self, index: int) -> float:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the short at the given index. 
		"""
		pass

	@overload
	def getUnsignedShort(self, index: int) -> int:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the unsigned short at the given index, represented as an int. 
		"""
		pass

	@overload
	def writeMedium(self, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setMedium(self, index: int, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readMedium(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the read medium value. 
		"""
		pass

	@overload
	def readUnsignedMedium(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the read unsigned medium value. 
		"""
		pass

	@overload
	def getMedium(self, index: int) -> int:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the medium at the given index. 
		"""
		pass

	@overload
	def getUnsignedMedium(self, index: int) -> int:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the unsigned medium at the given index. 
		"""
		pass

	@overload
	def writeInt(self, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setInt(self, index: int, value: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readInt(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the read int value. 
		"""
		pass

	@overload
	def readUnsignedInt(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read unsigned int value, represented as a long. 
		"""
		pass

	@overload
	def getInt(self, index: int) -> int:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the int at the given index. 
		"""
		pass

	@overload
	def getUnsignedInt(self, index: int) -> float:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the unsigned int at the given index, represented as a long. 
		"""
		pass

	@overload
	def writeLong(self, value: float) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setLong(self, index: int, value: float) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readLong(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read long value. 
		"""
		pass

	@overload
	def getLong(self, index: int) -> float:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the long at the given index. 
		"""
		pass

	@overload
	def writeFloat(self, value: float) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setFloat(self, index: int, value: float) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readFloat(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read float value. 
		"""
		pass

	@overload
	def getFloat(self, index: int) -> float:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the float at the given index. 
		"""
		pass

	@overload
	def writeDouble(self, value: float) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setDouble(self, index: int, value: float) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			index: the index to write to 
			value: the value to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readDouble(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the read double value. 
		"""
		pass

	@overload
	def getDouble(self, index: int) -> float:
		"""
		Since: 1.8.4 

		Args:
			index: the index to read from 

		Returns:
			the double at the given index. 
		"""
		pass

	@overload
	def writeZero(self, length: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			length: the amount of zeros to write 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setZero(self, index: int, length: int) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			length: the amount of zeros to write 
			index: the index to write to 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def writeBytes(self, bytes: List[float]) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			bytes: the bytes to store 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def setBytes(self, index: int, bytes: List[float]) -> "PacketByteBufferHelper":
		"""
		Since: 1.8.4 

		Args:
			bytes: the bytes to store 
			index: the index to write to 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def readBytes(self, length: int) -> List[float]:
		"""Starts reading from this buffer's readerIndex.\n
		Since: 1.8.4 

		Args:
			length: the length of the array to read 

		Returns:
			the read byte array. 
		"""
		pass

	@overload
	def getBytes(self, index: int, length: int) -> List[float]:
		"""
		Since: 1.8.4 

		Args:
			length: the length of the array to read 
			index: the index to start reading from 

		Returns:
			the read byte array . 
		"""
		pass

	@overload
	def skipBytes(self, length: int) -> "PacketByteBufferHelper":
		"""Moves the readerIndex of this buffer by the specified amount.\n
		Since: 1.8.4 

		Args:
			length: the amount of bytes to skip 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def getPacketName(self, packet: Packet) -> str:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def main(self, args: List[str]) -> None:
		pass

	pass





from typing import overload
from typing import List


class ScriptTrigger_TriggerType:
	"""
	Since: 1.0.0 [citation needed] 
	"""
	KEY_FALLING: "ScriptTrigger_TriggerType"
	KEY_RISING: "ScriptTrigger_TriggerType"
	KEY_BOTH: "ScriptTrigger_TriggerType"
	EVENT: "ScriptTrigger_TriggerType"

	@overload
	def values(self) -> List["ScriptTrigger_TriggerType"]:
		pass

	@overload
	def valueOf(self, name: str) -> "ScriptTrigger_TriggerType":
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent


class EventEXPChange(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	progress: float
	total: int
	level: int
	prevProgress: float
	prevTotal: int
	prevLevel: int

	@overload
	def __init__(self, progress: float, total: int, level: int, prevProgress: float, prevTotal: int, prevLevel: int) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_world_chunk_Palette_T_ = TypeVar("net_minecraft_world_chunk_Palette_T_")
Palette = net_minecraft_world_chunk_Palette_T_

net_minecraft_util_collection_PaletteStorage = TypeVar("net_minecraft_util_collection_PaletteStorage")
PaletteStorage = net_minecraft_util_collection_PaletteStorage


class IPalettedContainerData:

	@overload
	def jsmacros_getStorage(self) -> PaletteStorage:
		pass

	@overload
	def jsmacros_getPalette(self) -> Palette:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .MethodWrapper import MethodWrapper

java_util_regex_Pattern = TypeVar("java_util_regex_Pattern")
Pattern = java_util_regex_Pattern

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text


class TextHelper(BaseHelper):
	"""
	Since: 1.0.8 
	"""
	STRIP_FORMATTING_PATTERN: Pattern

	@overload
	def wrap(self, t: Text) -> "TextHelper":
		pass

	@overload
	def replaceFromJson(self, json: str) -> "TextHelper":
		"""replace the text in this class with JSON data.\n
		Since: 1.0.8 

		Args:
			json: 
		"""
		pass

	@overload
	def replaceFromString(self, content: str) -> "TextHelper":
		"""replace the text in this class with String data.\n
		Since: 1.0.8 

		Args:
			content: 
		"""
		pass

	@overload
	def getJson(self) -> str:
		"""
		Since: 1.2.7 

		Returns:
			JSON data representation. 
		"""
		pass

	@overload
	def getString(self) -> str:
		"""
		Since: 1.2.7 

		Returns:
			the text content. 
		"""
		pass

	@overload
	def getStringStripFormatting(self) -> str:
		"""
		Since: 1.6.5 

		Returns:
			the text content. stripped formatting when servers send it the (super) old way due to shitty coders. 
		"""
		pass

	@overload
	def withoutFormatting(self) -> "TextHelper":
		"""
		Since: 1.8.4 

		Returns:
			the text helper without the formatting applied. 
		"""
		pass

	@overload
	def visit(self, visitor: MethodWrapper) -> "TextHelper":
		"""
		Since: 1.6.5 

		Args:
			visitor: function with 2 args, no return. 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of this text. 
		"""
		pass

	@overload
	def toJson(self) -> str:
		"""
		Since: 1.0.8 
		"""
		pass

	@overload
	def toString(self) -> str:
		"""
		Since: 1.0.8, this used to do the same as TextHelper#getString() 

		Returns:
			String representation of text helper. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_data_DataTracker_SerializedEntry_java_util_Optional_net_minecraft_text_Text__ = TypeVar("net_minecraft_entity_data_DataTracker_SerializedEntry_java_util_Optional_net_minecraft_text_Text__")
DataTracker_SerializedEntry = net_minecraft_entity_data_DataTracker_SerializedEntry_java_util_Optional_net_minecraft_text_Text__

net_minecraft_entity_data_DataTracker_Entry_java_util_Optional_net_minecraft_text_Text__ = TypeVar("net_minecraft_entity_data_DataTracker_Entry_java_util_Optional_net_minecraft_text_Text__")
DataTracker_Entry = net_minecraft_entity_data_DataTracker_Entry_java_util_Optional_net_minecraft_text_Text__

org_spongepowered_asm_mixin_injection_callback_CallbackInfo = TypeVar("org_spongepowered_asm_mixin_injection_callback_CallbackInfo")
CallbackInfo = org_spongepowered_asm_mixin_injection_callback_CallbackInfo


class MixinDataTracker:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onCopyToFrom(self, to: DataTracker_Entry, from_: DataTracker_SerializedEntry, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from .Alignable import Alignable
from .RenderElementBuilder import RenderElementBuilder
from .IDraw2D import IDraw2D
from .CustomImage import CustomImage
from .Image import Image


class Image_Builder(Alignable, RenderElementBuilder):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, draw2D: IDraw2D) -> None:
		pass

	@overload
	def fromCustomImage(self, customImage: CustomImage) -> "Image_Builder":
		"""Will automatically set all attributes to the default values of the custom image.
Values set before the call of this method will be overwritten.\n
		Since: 1.8.4 

		Args:
			customImage: the custom image to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def identifier(self, identifier: str) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			identifier: the identifier of the image to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getIdentifier(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the identifier of the used image or 'null' if no image is used. 
		"""
		pass

	@overload
	def x(self, x: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position of the image. 
		"""
		pass

	@overload
	def y(self, y: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			y: the y position of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position of the image. 
		"""
		pass

	@overload
	def pos(self, x: int, y: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position of the image 
			y: the y position of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def width(self, width: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the image. 
		"""
		pass

	@overload
	def height(self, height: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			height: the height of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the image. 
		"""
		pass

	@overload
	def size(self, width: int, height: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			width: the width of the image 
			height: the height of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def imageX(self, imageX: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			imageX: the x position in the image texture to start drawing from 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getImageX(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the x position in the image texture to start drawing from. 
		"""
		pass

	@overload
	def imageY(self, imageY: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			imageY: the y position in the image texture to start drawing from 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getImageY(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the y position in the image texture to start drawing from. 
		"""
		pass

	@overload
	def imagePos(self, imageX: int, imageY: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			imageY: the y position in the image texture to start drawing from 
			imageX: the x position in the image texture to start drawing from 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def regionWidth(self, regionWidth: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			regionWidth: the width of the region to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRegionWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the region to draw. 
		"""
		pass

	@overload
	def regionHeight(self, regionHeight: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			regionHeight: the height of the region to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRegionHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the region to draw. 
		"""
		pass

	@overload
	def regionSize(self, regionWidth: int, regionHeight: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			regionHeight: the height of the region to draw 
			regionWidth: the width of the region to draw 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def regions(self, x: int, y: int, width: int, height: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			x: the x position in the image texture to start drawing from 
			width: the width of the region to draw 
			y: the y position in the image texture to start drawing from 
			height: the height of the region to draw 
		"""
		pass

	@overload
	def regions(self, x: int, y: int, width: int, height: int, textureWidth: int, textureHeight: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			textureWidth: the width of the used texture 
			x: the x position in the image texture to start drawing from 
			width: the width of the region to draw 
			y: the y position in the image texture to start drawing from 
			textureHeight: the height of the used texture 
			height: the height of the region to draw 
		"""
		pass

	@overload
	def textureWidth(self, textureWidth: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			textureWidth: the width of the used texture 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getTextureWidth(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the width of the used texture. 
		"""
		pass

	@overload
	def textureHeight(self, textureHeight: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			textureHeight: the height of the used texture 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getTextureHeight(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the height of the used texture. 
		"""
		pass

	@overload
	def textureSize(self, textureWidth: int, textureHeight: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			textureWidth: the width of the used texture 
			textureHeight: the height of the used texture 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, color: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, r: int, g: int, b: int, a: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			a: the alpha component of the color 
			r: the red component of the color 
			b: the blue component of the color 
			g: the green component of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def color(self, color: int, alpha: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			color: the color of the image 
			alpha: the alpha value of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getColor(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the color of the image. 
		"""
		pass

	@overload
	def alpha(self, alpha: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			alpha: the alpha value of the color 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAlpha(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the alpha value of the color. 
		"""
		pass

	@overload
	def rotation(self, rotation: float) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotation: the rotation (clockwise) of the image in degrees 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRotation(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the rotation (clockwise) of the image in degrees. 
		"""
		pass

	@overload
	def rotateCenter(self, rotateCenter: bool) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			rotateCenter: whether the image should be rotated around its center 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def isRotatingCenter(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this image should be rotated around its center, 'false' otherwise. 
		"""
		pass

	@overload
	def zIndex(self, zIndex: int) -> "Image_Builder":
		"""
		Since: 1.8.4 

		Args:
			zIndex: the z-index of the image 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getZIndex(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the z-index of the image. 
		"""
		pass

	@overload
	def createElement(self) -> Image:
		pass

	@overload
	def getScaledWidth(self) -> int:
		pass

	@overload
	def getParentWidth(self) -> int:
		pass

	@overload
	def getScaledHeight(self) -> int:
		pass

	@overload
	def getParentHeight(self) -> int:
		pass

	@overload
	def getScaledLeft(self) -> int:
		pass

	@overload
	def getScaledTop(self) -> int:
		pass

	@overload
	def moveTo(self, x: int, y: int) -> "Image_Builder":
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

net_minecraft_entity_player_PlayerAbilities = TypeVar("net_minecraft_entity_player_PlayerAbilities")
PlayerAbilities = net_minecraft_entity_player_PlayerAbilities


class PlayerAbilitiesHelper(BaseHelper):
	"""
	Since: 1.0.3 
	"""

	@overload
	def __init__(self, a: PlayerAbilities) -> None:
		pass

	@overload
	def getInvulnerable(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			whether the player can be damaged. 
		"""
		pass

	@overload
	def getFlying(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			if the player is currently flying. 
		"""
		pass

	@overload
	def getAllowFlying(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			if the player is allowed to fly. 
		"""
		pass

	@overload
	def getCreativeMode(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			if the player is in creative. 
		"""
		pass

	@overload
	def canModifyWorld(self) -> bool:
		"""Even if this method returns true, the player may not be able to modify the world due to other
restrictions such as plugins and mods. Modifying the world includes, placing, breaking or
interacting with blocks.\n
		Since: 1.8.4 

		Returns:
			'true' if the player is allowed to modify the world, 'false' otherwise. 
		"""
		pass

	@overload
	def setFlying(self, b: bool) -> "PlayerAbilitiesHelper":
		"""set the player flying state.\n
		Since: 1.0.3 

		Args:
			b: 
		"""
		pass

	@overload
	def setAllowFlying(self, b: bool) -> "PlayerAbilitiesHelper":
		"""set the player allow flying state.\n
		Since: 1.0.3 

		Args:
			b: 
		"""
		pass

	@overload
	def getFlySpeed(self) -> float:
		"""
		Since: 1.0.3 

		Returns:
			the player fly speed multiplier. 
		"""
		pass

	@overload
	def setFlySpeed(self, flySpeed: float) -> "PlayerAbilitiesHelper":
		"""set the player fly speed multiplier.\n
		Since: 1.0.3 

		Args:
			flySpeed: 
		"""
		pass

	@overload
	def getWalkSpeed(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the player's walk speed. 
		"""
		pass

	@overload
	def setWalkSpeed(self, speed: float) -> "PlayerAbilitiesHelper":
		"""
		Since: 1.8.4 

		Args:
			speed: the new walk speed 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from .BaseLibrary import BaseLibrary
from .Inventory import Inventory
from .ClientPlayerEntityHelper import ClientPlayerEntityHelper
from .InteractionManagerHelper import InteractionManagerHelper
from .BlockDataHelper import BlockDataHelper
from .HitResultHelper_Block import HitResultHelper_Block
from .EntityHelper import EntityHelper
from .MethodWrapper import MethodWrapper
from .StatsHelper import StatsHelper
from .PlayerInput import PlayerInput
from .Pos3D import Pos3D


class FPlayer(BaseLibrary):
	"""Functions for getting and modifying the player's state. 
An instance of this class is passed to scripts as the 'Player' variable.
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def openInventory(self) -> Inventory:
		"""

		Returns:
			the Inventory handler 
		"""
		pass

	@overload
	def getPlayer(self) -> ClientPlayerEntityHelper:
		"""
		Since: 1.0.3 

		Returns:
			the player entity wrapper. 
		"""
		pass

	@overload
	def getInteractionManager(self) -> InteractionManagerHelper:
		"""
		Since: 1.9.0 
		"""
		pass

	@overload
	def interactions(self) -> InteractionManagerHelper:
		"""alias for FPlayer#getInteractionManager()\n
		Since: 1.9.0 
		"""
		pass

	@overload
	def getGameMode(self) -> str:
		"""
		Since: 1.0.9 

		Returns:
			the player's current gamemode. 
		"""
		pass

	@overload
	def setGameMode(self, gameMode: str) -> None:
		"""
		Since: 1.8.4 

		Args:
			gameMode: possible values are survival, creative, adventure, spectator (case insensitive) 
		"""
		pass

	@overload
	def rayTraceBlock(self, distance: float, fluid: bool) -> BlockDataHelper:
		"""
		Since: 1.0.5 

		Args:
			distance: 
			fluid: 

		Returns:
			the block/liquid the player is currently looking at. 
		"""
		pass

	@overload
	def detailedRayTraceBlock(self, distance: float, fluid: bool) -> HitResultHelper_Block:
		"""
		Since: 1.9.1 

		Returns:
			the raycast result. 
		"""
		pass

	@overload
	def rayTraceEntity(self) -> EntityHelper:
		"""
		Since: 1.0.5 

		Returns:
			the entity the camera is currently looking at. can be affected by InteractionManagerHelper#setTarget(xyz.wagyourtail.jsmacros.client.api.helpers.world.entity.EntityHelper<?>) 
		"""
		pass

	@overload
	def rayTraceEntity(self, distance: int) -> EntityHelper:
		"""
		Since: 1.8.3 

		Args:
			distance: 

		Returns:
			entity the player entity is currently looking at (if any). 
		"""
		pass

	@overload
	def writeSign(self, l1: str, l2: str, l3: str, l4: str) -> bool:
		"""Write to a sign screen if a sign screen is currently open.\n
		Since: 1.2.2 

		Args:
			l1: 
			l2: 
			l3: 
			l4: 

		Returns:
			of success. 
		"""
		pass

	@overload
	def takeScreenshot(self, folder: str, callback: MethodWrapper) -> None:
		"""
		Since: 1.2.6 

		Args:
			folder: 
			callback: calls your method as a Consumer TextHelper 
		"""
		pass

	@overload
	def takeScreenshot(self, folder: str, file: str, callback: MethodWrapper) -> None:
		"""Take a screenshot and save to a file. 
'file' is the optional one, typescript doesn't like it not being the last one that's optional\n
		Since: 1.2.6 

		Args:
			folder: 
			file: 
			callback: calls your method as a Consumer TextHelper 
		"""
		pass

	@overload
	def takePanorama(self, folder: str, width: int, height: int, callback: MethodWrapper) -> None:
		"""
		Since: 1.8.4 

		Args:
			folder: the folder to save the screenshot to, relative to the macro folder 
			width: the width of the panorama 
			callback: calls your method as a Consumer TextHelper 
			height: the height of the panorama 
		"""
		pass

	@overload
	def getStatistics(self) -> StatsHelper:
		pass

	@overload
	def getReach(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current reach distance of the player. 
		"""
		pass

	@overload
	def createPlayerInput(self) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def createPlayerInput(self, movementForward: float, movementSideways: float, yaw: float) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def createPlayerInput(self, movementForward: float, yaw: float, jumping: bool, sprinting: bool) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def createPlayerInput(self, movementForward: float, movementSideways: float, yaw: float, pitch: float, jumping: bool, sneaking: bool, sprinting: bool) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 

		Args:
			movementForward: 1 = forward input (W); 0 = no input; -1 = backward input (S) 
			sprinting: sprint input 
			jumping: jump input 
			sneaking: sneak input 
			pitch: pitch of the player 
			yaw: yaw of the player 
			movementSideways: 1 = left input (A); 0 = no input; -1 = right input (D) 
		"""
		pass

	@overload
	def createPlayerInputsFromCsv(self, csv: str) -> List[PlayerInput]:
		"""Parses each row of CSV string into a 'PlayerInput' .
The capitalization of the header matters. About the columns:  
-  'movementForward' and 'movementSideways' as a number  
- 'yaw' and 'pitch' as an absolute number  
- 'jumping' , 'sneaking' and 'sprinting' have to be boolean   
The separation must be a "," it's a csv...(but spaces don't matter) Quoted values don't work\n
		Since: 1.4.0 

		Args:
			csv: CSV string to be parsed 
		"""
		pass

	@overload
	def createPlayerInputsFromJson(self, json: str) -> PlayerInput:
		"""Parses a JSON string into a 'PlayerInput' Object.
For details see 'PlayerInput.fromCsv()' , on what has to be present. Capitalization of the keys matters.\n
		Since: 1.4.0 

		Args:
			json: JSON string to be parsed 

		Returns:
			The JSON parsed into a 'PlayerInput' 
		"""
		pass

	@overload
	def getCurrentPlayerInput(self) -> PlayerInput:
		"""Creates a new 'PlayerInput' object with the current inputs of the player.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def addInput(self, input: PlayerInput) -> None:
		"""Adds a new 'PlayerInput' to 'MovementQueue' to be executed\n
		Since: 1.4.0 

		Args:
			input: the PlayerInput to be executed 
		"""
		pass

	@overload
	def addInputs(self, inputs: List[PlayerInput]) -> None:
		"""Adds multiple new 'PlayerInput' to 'MovementQueue' to be executed\n
		Since: 1.4.0 

		Args:
			inputs: the PlayerInputs to be executed 
		"""
		pass

	@overload
	def clearInputs(self) -> None:
		"""Clears all inputs in the 'MovementQueue'\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def setDrawPredictions(self, val: bool) -> None:
		pass

	@overload
	def predictInput(self, input: PlayerInput) -> Pos3D:
		"""Predicts where one tick with a 'PlayerInput' as input would lead to.\n
		Since: 1.4.0 

		Args:
			input: the PlayerInput for the prediction 

		Returns:
			the position after the input 
		"""
		pass

	@overload
	def predictInput(self, input: PlayerInput, draw: bool) -> Pos3D:
		"""Predicts where one tick with a 'PlayerInput' as input would lead to.\n
		Since: 1.4.0 

		Args:
			input: the PlayerInput for the prediction 
			draw: whether to visualize the result or not 

		Returns:
			the position after the input 
		"""
		pass

	@overload
	def predictInputs(self, inputs: List[PlayerInput]) -> List[Pos3D]:
		"""Predicts where each 'PlayerInput' executed in a row would lead
without drawing it.\n
		Since: 1.4.0 

		Args:
			inputs: the PlayerInputs for each tick for the prediction 

		Returns:
			the position after each input 
		"""
		pass

	@overload
	def isBreakingBlock(self) -> bool:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def predictInputs(self, inputs: List[PlayerInput], draw: bool) -> List[Pos3D]:
		"""Predicts where each 'PlayerInput' executed in a row would lead\n
		Since: 1.4.0 

		Args:
			inputs: the PlayerInputs for each tick for the prediction 
			draw: whether to visualize the result or not 

		Returns:
			the position after each input 
		"""
		pass

	@overload
	def moveForward(self, yaw: float) -> None:
		"""Adds a forward movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.0 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	@overload
	def moveBackward(self, yaw: float) -> None:
		"""Adds a backward movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.0 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	@overload
	def moveStrafeLeft(self, yaw: float) -> None:
		"""Adds sideways movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.2 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	@overload
	def moveStrafeRight(self, yaw: float) -> None:
		"""Adds sideways movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.2 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Any
from .MobEntityHelper import MobEntityHelper
from .EntityHelper import EntityHelper

net_minecraft_entity_boss_dragon_EnderDragonEntity = TypeVar("net_minecraft_entity_boss_dragon_EnderDragonEntity")
EnderDragonEntity = net_minecraft_entity_boss_dragon_EnderDragonEntity


class EnderDragonEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: EnderDragonEntity) -> None:
		pass

	@overload
	def getPhase(self) -> str:
		"""The phases are as follows: 
'HoldingPattern' , 'StrafePlayer' , 'LandingApproach' , 'Landing' , 'Takeoff' , 'SittingFlaming' , 'SittingScanning' , 'SittingAttacking' , 'ChargingPlayer' , 'Dying' , 'Hover'\n
		Since: 1.8.4 

		Returns:
			the current phase of the dragon. 
		"""
		pass

	@overload
	def getBodyPart(self, index: int) -> EntityHelper:
		"""
		Since: 1.8.4 

		Args:
			index: the index of the dragon's body part to get 

		Returns:
			the specified body part of the dragon. 
		"""
		pass

	@overload
	def getBodyParts(self) -> List[Any]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all body parts of the dragon. 
		"""
		pass

	@overload
	def getBodyParts(self, name: str) -> List[Any]:
		"""The name can be either 'head' , 'neck' , 'body' , 'tail' or 'wing' .\n
		Since: 1.8.4 

		Args:
			name: the name of the body part to get 

		Returns:
			a list of all body parts of the dragon with the specified name. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import Mapping
from .OptionsHelper import OptionsHelper


class OptionsHelper_MusicOptionsHelper:
	parent: OptionsHelper

	@overload
	def __init__(self, OptionsHelper: OptionsHelper) -> None:
		pass

	@overload
	def getParent(self) -> OptionsHelper:
		"""
		Since: 1.8.4 

		Returns:
			the parent options helper. 
		"""
		pass

	@overload
	def getMasterVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current master volume. 
		"""
		pass

	@overload
	def setMasterVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new master volume 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getMusicVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current music volume. 
		"""
		pass

	@overload
	def setMusicVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new music volume 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getRecordsVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current value of played recods. 
		"""
		pass

	@overload
	def setRecordsVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new volume for playing records 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getWeatherVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current volume of the weather. 
		"""
		pass

	@overload
	def setWeatherVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new volume for the weather 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getBlocksVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current volume of block related sounds. 
		"""
		pass

	@overload
	def setBlocksVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new volume for block sounds 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getHostileVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current volume of hostile mobs. 
		"""
		pass

	@overload
	def setHostileVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new volume for hostile mobs 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getNeutralVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current volume of neutral mobs. 
		"""
		pass

	@overload
	def setNeutralVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new volume for neutral mobs 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getPlayerVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current player volume. 
		"""
		pass

	@overload
	def setPlayerVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new player volume 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAmbientVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current ambient volume. 
		"""
		pass

	@overload
	def setAmbientVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new ambient volume 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getVoiceVolume(self) -> float:
		"""
		Since: 1.8.4 

		Returns:
			the current voice volume. 
		"""
		pass

	@overload
	def setVoiceVolume(self, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getVolume(self, category: str) -> float:
		"""
		Since: 1.8.4 

		Args:
			category: the category to get the volume of 

		Returns:
			the volume of the given sound category. 
		"""
		pass

	@overload
	def getVolumes(self) -> Mapping[str, Float]:
		"""
		Since: 1.8.4 

		Returns:
			a map of all sound categories and their volumes. 
		"""
		pass

	@overload
	def setVolume(self, category: str, volume: float) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			volume: the new volume 
			category: the category to set the volume for 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getSoundDevice(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the currently selected sound device. 
		"""
		pass

	@overload
	def setSoundDevice(self, audioDevice: str) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			audioDevice: the audio device to use 

		Returns:
			self for chaining. 
		"""
		pass

	@overload
	def getAudioDevices(self) -> List[str]:
		"""
		Since: 1.8.4 

		Returns:
			a list of all connected audio devices. 
		"""
		pass

	@overload
	def areSubtitlesShown(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if subtitles should be shown, 'false' otherwise. 
		"""
		pass

	@overload
	def showSubtitles(self, val: bool) -> "OptionsHelper_MusicOptionsHelper":
		"""
		Since: 1.8.4 

		Args:
			val: whether subtitles should be shown or not 

		Returns:
			self for chaining. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .Inventory import Inventory
from .ItemStackHelper import ItemStackHelper

net_minecraft_client_gui_screen_ingame_SmithingScreen = TypeVar("net_minecraft_client_gui_screen_ingame_SmithingScreen")
SmithingScreen = net_minecraft_client_gui_screen_ingame_SmithingScreen


class SmithingInventory(Inventory):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, inventory: SmithingScreen) -> None:
		pass

	@overload
	def getLeftInput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the left input item. 
		"""
		pass

	@overload
	def getRightInput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the right input item. 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.8.4 

		Returns:
			the expected output item. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .AnimalEntityHelper import AnimalEntityHelper

net_minecraft_entity_passive_RabbitEntity = TypeVar("net_minecraft_entity_passive_RabbitEntity")
RabbitEntity = net_minecraft_entity_passive_RabbitEntity


class RabbitEntityHelper(AnimalEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: RabbitEntity) -> None:
		pass

	@overload
	def getVariant(self) -> str:
		"""
		Since: 1.8.4 

		Returns:
			the variant of this rabbit. 
		"""
		pass

	@overload
	def isKillerBunny(self) -> bool:
		"""
		Since: 1.8.4 

		Returns:
			'true' if this rabbit is a killer bunny, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar

net_minecraft_entity_boss_BossBar_Style = TypeVar("net_minecraft_entity_boss_BossBar_Style")
BossBar_Style = net_minecraft_entity_boss_BossBar_Style

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

net_minecraft_network_packet_s2c_play_BossBarS2CPacket_Consumer = TypeVar("net_minecraft_network_packet_s2c_play_BossBarS2CPacket_Consumer")
BossBarS2CPacket_Consumer = net_minecraft_network_packet_s2c_play_BossBarS2CPacket_Consumer

java_util_UUID = TypeVar("java_util_UUID")
UUID = java_util_UUID

net_minecraft_entity_boss_BossBar_Color = TypeVar("net_minecraft_entity_boss_BossBar_Color")
BossBar_Color = net_minecraft_entity_boss_BossBar_Color


class BossBarConsumer(BossBarS2CPacket_Consumer):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def add(self, uuid: UUID, name: Text, percent: float, color: BossBar_Color, style: BossBar_Style, darkenSky: bool, dragonMusic: bool, thickenFog: bool) -> None:
		pass

	@overload
	def remove(self, uuid: UUID) -> None:
		pass

	@overload
	def updateProgress(self, uuid: UUID, percent: float) -> None:
		pass

	@overload
	def updateName(self, uuid: UUID, name: Text) -> None:
		pass

	@overload
	def updateStyle(self, id: UUID, color: BossBar_Color, style: BossBar_Style) -> None:
		pass

	@overload
	def updateProperties(self, uuid: UUID, darkenSky: bool, dragonMusic: bool, thickenFog: bool) -> None:
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .Pos3D import Pos3D


class EventSound(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	sound: str
	volume: float
	pitch: float
	position: Pos3D

	@overload
	def __init__(self, sound: str, volume: float, pitch: float, x: float, y: float, z: float) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

net_minecraft_client_gui_hud_ChatHudLine = TypeVar("net_minecraft_client_gui_hud_ChatHudLine")
ChatHudLine = net_minecraft_client_gui_hud_ChatHudLine

net_minecraft_client_gui_hud_ChatHud = TypeVar("net_minecraft_client_gui_hud_ChatHud")
ChatHud = net_minecraft_client_gui_hud_ChatHud


class ChatHudLineHelper(BaseHelper):

	@overload
	def __init__(self, base: ChatHudLine, hud: ChatHud) -> None:
		pass

	@overload
	def getText(self) -> TextHelper:
		pass

	@overload
	def getCreationTick(self) -> int:
		pass

	@overload
	def deleteById(self) -> "ChatHudLineHelper":
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .IOverlayParent import IOverlayParent

java_util_function_Consumer_java_lang_Integer_ = TypeVar("java_util_function_Consumer_java_lang_Integer_")
Consumer = java_util_function_Consumer_java_lang_Integer_

net_minecraft_client_gui_DrawContext = TypeVar("net_minecraft_client_gui_DrawContext")
DrawContext = net_minecraft_client_gui_DrawContext

net_minecraft_text_Text = TypeVar("net_minecraft_text_Text")
Text = net_minecraft_text_Text

net_minecraft_client_font_TextRenderer = TypeVar("net_minecraft_client_font_TextRenderer")
TextRenderer = net_minecraft_client_font_TextRenderer


class ListContainer(MultiElementContainer):
	onSelect: Consumer

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, list: List[Text], parent: IOverlayParent, onSelect: Consumer) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def addItem(self, name: Text) -> None:
		pass

	@overload
	def setSelected(self, index: int) -> None:
		pass

	@overload
	def onScrollbar(self, page: float) -> None:
		pass

	@overload
	def render(self, drawContext: DrawContext, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

java_util_Comparator_java_lang_String_ = TypeVar("java_util_Comparator_java_lang_String_")
Comparator = java_util_Comparator_java_lang_String_


class Sorting_SortServiceByName(Comparator):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def compare(self, a: str, b: str) -> int:
		pass

	pass





from typing import overload


class IResourcePackManager:

	@overload
	def jsmacros_disableServerPacks(self, disable: bool) -> None:
		pass

	@overload
	def jsmacros_isServerPacksDisabled(self) -> bool:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .EntityHelper import EntityHelper
from .Pos3D import Pos3D

net_minecraft_util_math_BlockPos = TypeVar("net_minecraft_util_math_BlockPos")
BlockPos = net_minecraft_util_math_BlockPos


class BlockPosHelper(BaseHelper):
	"""
	Since: 1.2.6 
	"""

	@overload
	def __init__(self, b: BlockPos) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, z: int) -> None:
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			the 'x' value of the block. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			the 'y' value of the block. 
		"""
		pass

	@overload
	def getZ(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			the 'z' value of the block. 
		"""
		pass

	@overload
	def up(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block above. 
		"""
		pass

	@overload
	def up(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: the distance to move up 

		Returns:
			the block n-th block above. 
		"""
		pass

	@overload
	def down(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block below. 
		"""
		pass

	@overload
	def down(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: the distance to move down 

		Returns:
			the block n-th block below. 
		"""
		pass

	@overload
	def north(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the north. 
		"""
		pass

	@overload
	def north(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: the distance to move north 

		Returns:
			the n-th block to the north. 
		"""
		pass

	@overload
	def south(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the south. 
		"""
		pass

	@overload
	def south(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: the distance to move south 

		Returns:
			the n-th block to the south. 
		"""
		pass

	@overload
	def east(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the east. 
		"""
		pass

	@overload
	def east(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: the distance to move east 

		Returns:
			the n-th block to the east. 
		"""
		pass

	@overload
	def west(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the west. 
		"""
		pass

	@overload
	def west(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: the distance to move west 

		Returns:
			the n-th block to the west. 
		"""
		pass

	@overload
	def offset(self, direction: str) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 

		Returns:
			the block offset by the given direction. 
		"""
		pass

	@overload
	def offset(self, direction: str, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: the distance to move in the given direction 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 

		Returns:
			the n-th block offset by the given direction. 
		"""
		pass

	@overload
	def offset(self, x: int, y: int, z: int) -> "BlockPosHelper":
		"""
		Since: 1.8.4 

		Args:
			x: the x offset 
			y: the y offset 
			z: the y offset 

		Returns:
			the block offset by the given values. 
		"""
		pass

	@overload
	def toNetherCoords(self) -> "BlockPosHelper":
		"""
		Since: 1.8.4 

		Returns:
			the block position converted to the respective nether coordinates. 
		"""
		pass

	@overload
	def toOverworldCoords(self) -> "BlockPosHelper":
		"""
		Since: 1.8.4 

		Returns:
			the block position converted to the respective overworld coordinates. 
		"""
		pass

	@overload
	def distanceTo(self, entity: EntityHelper) -> float:
		"""
		Since: 1.8.4 

		Args:
			entity: the entity to get the distance to 

		Returns:
			the distance of this position to the given entity. 
		"""
		pass

	@overload
	def distanceTo(self, pos: "BlockPosHelper") -> float:
		"""
		Since: 1.8.4 

		Args:
			pos: the position to get the distance to 

		Returns:
			the distance of this position to the given position. 
		"""
		pass

	@overload
	def distanceTo(self, pos: Pos3D) -> float:
		"""
		Since: 1.8.4 

		Args:
			pos: the position to get the distance to 

		Returns:
			the distance of this position to the given position. 
		"""
		pass

	@overload
	def distanceTo(self, x: float, y: float, z: float) -> float:
		"""
		Since: 1.8.4 

		Args:
			x: the x coordinate to get the distance to 
			y: the y coordinate to get the distance to 
			z: the z coordinate to get the distance to 

		Returns:
			the distance of this position to the given position. 
		"""
		pass

	@overload
	def toPos3D(self) -> Pos3D:
		"""
		Since: 1.8.4 

		Returns:
			the Pos3D representation of this position. 
		"""
		pass

	@overload
	def equals(self, obj: object) -> bool:
		pass

	@overload
	def hashCode(self) -> int:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MobEntityHelper import MobEntityHelper

net_minecraft_entity_mob_SlimeEntity = TypeVar("net_minecraft_entity_mob_SlimeEntity")
SlimeEntity = net_minecraft_entity_mob_SlimeEntity


class SlimeEntityHelper(MobEntityHelper):
	"""
	Since: 1.8.4 
	"""

	@overload
	def __init__(self, base: SlimeEntity) -> None:
		pass

	@overload
	def getSize(self) -> int:
		"""
		Since: 1.8.4 

		Returns:
			the size of this slime. 
		"""
		pass

	@overload
	def isSmall(self) -> bool:
		"""Small slimes, with a size less than 1, don't attack the player.\n
		Since: 1.8.4 

		Returns:
			'true' if this slime is small, 'false' otherwise. 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .PlayerInput import PlayerInput

net_minecraft_entity_LivingEntity = TypeVar("net_minecraft_entity_LivingEntity")
LivingEntity = net_minecraft_entity_LivingEntity

java_lang_Iterable_net_minecraft_item_ItemStack_ = TypeVar("java_lang_Iterable_net_minecraft_item_ItemStack_")
Iterable = java_lang_Iterable_net_minecraft_item_ItemStack_

net_minecraft_entity_EquipmentSlot = TypeVar("net_minecraft_entity_EquipmentSlot")
EquipmentSlot = net_minecraft_entity_EquipmentSlot

net_minecraft_util_math_Box = TypeVar("net_minecraft_util_math_Box")
Box = net_minecraft_util_math_Box

net_minecraft_client_network_ClientPlayerEntity = TypeVar("net_minecraft_client_network_ClientPlayerEntity")
ClientPlayerEntity = net_minecraft_client_network_ClientPlayerEntity

net_minecraft_world_World = TypeVar("net_minecraft_world_World")
World = net_minecraft_world_World

net_minecraft_item_ItemStack = TypeVar("net_minecraft_item_ItemStack")
ItemStack = net_minecraft_item_ItemStack

net_minecraft_util_Arm = TypeVar("net_minecraft_util_Arm")
Arm = net_minecraft_util_Arm

net_minecraft_util_math_Vec3d = TypeVar("net_minecraft_util_math_Vec3d")
Vec3d = net_minecraft_util_math_Vec3d


class MovementDummy(LivingEntity):

	@overload
	def __init__(self, player: "MovementDummy") -> None:
		pass

	@overload
	def __init__(self, player: ClientPlayerEntity) -> None:
		pass

	@overload
	def __init__(self, world: World, pos: Vec3d, velocity: Vec3d, hitBox: Box, onGround: bool, isSprinting: bool, isSneaking: bool) -> None:
		pass

	@overload
	def getCoordsHistory(self) -> List[Vec3d]:
		pass

	@overload
	def getInputs(self) -> List[PlayerInput]:
		pass

	@overload
	def applyInput(self, input: PlayerInput) -> Vec3d:
		pass

	@overload
	def applyMovementInput(self, movementInput: Vec3d, f: float) -> Vec3d:
		"""We have to do this "inject" since the the applyClimbingSpeed() method
in LivingEntity is checking if we are a PlayerEntity, we want to apply the outcome of this check,
so this is why we need to set the y-velocity to 0.
		"""
		pass

	@overload
	def canMoveVoluntarily(self) -> bool:
		pass

	@overload
	def setSprinting(self, sprinting: bool) -> None:
		pass

	@overload
	def getMainHandStack(self) -> ItemStack:
		pass

	@overload
	def getArmorItems(self) -> Iterable:
		pass

	@overload
	def getEquippedStack(self, slot: EquipmentSlot) -> ItemStack:
		pass

	@overload
	def equipStack(self, slot: EquipmentSlot, stack: ItemStack) -> None:
		pass

	@overload
	def getMainArm(self) -> Arm:
		pass

	@overload
	def clone(self) -> "MovementDummy":
		pass

	pass


